Globals - Betty documentation

Hide navigation sidebar
Hide table of contents sidebar
Skip to content
Back to top
View this page
Toggle table of contents sidebar

# Globals

Jinja2 globals are often data or functions that do not are not filters or tests.

In addition to Jinja2’s built-in globals, Betty provides the following:

`app` (`betty.app.App`)

  The currently running Betty application.

`project` (`betty.project.Project`)

  The project the template is being rendered for.

`today` (`betty.date.Date`)

  The current date.